{ "sec:object", "nipguidese34.html#nip_label_sec:object" },
{ "sec:menu-colour", "nipguidese14.html#nip_label_sec:menu-colour" },
{ "tb:colour", "nipguidese14.html#nip_label_tb:colour" },
{ "sec:pattern", "nipguidese30.html#nip_label_sec:pattern" },
{ "sec:nerdtour", "nipguidese3.html#nip_label_sec:nerdtour" },
{ "fg:Fred", "nipguidese3.html#nip_label_fg:Fred" },
{ "fg:mainFred", "nipguidese3.html#nip_label_fg:mainFred" },
{ "fg:slideFred", "nipguidese3.html#nip_label_fg:slideFred" },
{ "fg:Jim", "nipguidese3.html#nip_label_fg:Jim" },
{ "fg:twomoreregions", "nipguidese3.html#nip_label_fg:twomoreregions" },
{ "fg:myjoin", "nipguidese3.html#nip_label_fg:myjoin" },
{ "sec:menu-object", "nipguidese20.html#nip_label_sec:menu-object" },
{ "sec:operators", "nipguidese27.html#nip_label_sec:operators" },
{ "tb:precedence", "nipguidese27.html#nip_label_tb:precedence" },
{ "sec:listsyntax", "nipguidese27.html#nip_label_sec:listsyntax" },
{ "sec:func", "nipguidese27.html#nip_label_sec:func" },
{ "sec:vidpref", "nipguidese4.html#nip_label_sec:vidpref" },
{ "fg:vidpref", "nipguidese4.html#nip_label_fg:vidpref" },
{ "sec:imcap", "nipguidese4.html#nip_label_sec:imcap" },
{ "sec:grey", "nipguidese4.html#nip_label_sec:grey" },
{ "sec:linuxgrey", "nipguidese4.html#nip_label_sec:linuxgrey" },
{ "sec:wingrey", "nipguidese4.html#nip_label_sec:wingrey" },
{ "sec:lists", "nipguidese28.html#nip_label_sec:lists" },
{ "tb:list", "nipguidese28.html#nip_label_tb:list" },
{ "sec:cmdline", "nipguidese13.html#nip_label_sec:cmdline" },
{ "sec:menu-histogram", "nipguidese16.html#nip_label_sec:menu-histogram" },
{ "sec:menu-matrix", "nipguidese19.html#nip_label_sec:menu-matrix" },
{ "sec:quicktour", "nipguidese1.html#nip_label_sec:quicktour" },
{ "fg:loadedimage", "nipguidese1.html#nip_label_fg:loadedimage" },
{ "fg:imageview", "nipguidese1.html#nip_label_fg:imageview" },
{ "tb:shortcuts", "nipguidese1.html#nip_label_tb:shortcuts" },
{ "fg:imageviewregion", "nipguidese1.html#nip_label_fg:imageviewregion" },
{ "fg:main2regions", "nipguidese1.html#nip_label_fg:main2regions" },
{ "fg:rotate", "nipguidese1.html#nip_label_fg:rotate" },
{ "fg:join", "nipguidese1.html#nip_label_fg:join" },
{ "fg:browse", "nipguidese1.html#nip_label_fg:browse" },
{ "tb:builtin", "nipguidese24.html#nip_label_tb:builtin" },
{ "tb:toolkits", "nipguidese31.html#nip_label_tb:toolkits" },
{ "sec:menu-filter", "nipguidese15.html#nip_label_sec:menu-filter" },
{ "sec:progwin", "nipguidese12.html#nip_label_sec:progwin" },
{ "sec:trace", "nipguidese12.html#nip_label_sec:trace" },
{ "sec:menu-tasks", "nipguidese21.html#nip_label_sec:menu-tasks" },
{ "sec:menu-capture", "nipguidese21.html#nip_label_sec:menu-capture" },
{ "sec:menu-mosaic", "nipguidese21.html#nip_label_sec:menu-mosaic" },
{ "sec:menu-picture-frame", "nipguidese21.html#nip_label_sec:menu-picture-frame" },
{ "sec:menu-print", "nipguidese21.html#nip_label_sec:menu-print" },
{ "sec:bowser", "nipguidese33.html#nip_label_sec:bowser" },
{ "sec:tools", "nipguidese33.html#nip_label_sec:tools" },
{ "fg:toolkit", "nipguidese33.html#nip_label_fg:toolkit" },
{ "fg:toolkit2", "nipguidese33.html#nip_label_fg:toolkit2" },
{ "fg:toolkit3", "nipguidese33.html#nip_label_fg:toolkit3" },
{ "sec:workspaces", "nipguidese33.html#nip_label_sec:workspaces" },
{ "fg:row2", "nipguidese33.html#nip_label_fg:row2" },
{ "tb:classes", "nipguidese33.html#nip_label_tb:classes" },
{ "sec:Image", "nipguidese33.html#nip_label_sec:Image" },
{ "sec:colour", "nipguidese33.html#nip_label_sec:colour" },
{ "sec:loadsave", "nipguidese10.html#nip_label_sec:loadsave" },
{ "fg:open", "nipguidese10.html#nip_label_fg:open" },
{ "fg:save", "nipguidese10.html#nip_label_fg:save" },
{ "sec:view", "nipguidese9.html#nip_label_sec:view" },
{ "fg:scr3", "nipguidese9.html#nip_label_fg:scr3" },
{ "fg:scr4", "nipguidese9.html#nip_label_fg:scr4" },
{ "sec:paintbox", "nipguidese9.html#nip_label_sec:paintbox" },
{ "fg:paint", "nipguidese9.html#nip_label_fg:paint" },
{ "sec:program", "nipguidech6.html#nip_label_sec:program" },
{ "sec:lazy", "nipguidese29.html#nip_label_sec:lazy" },
{ "sec:optimise", "nipguidese35.html#nip_label_sec:optimise" },
{ "sec:menus", "nipguidech5.html#nip_label_sec:menus" },
{ "sec:ipwindow", "nipguidese11.html#nip_label_sec:ipwindow" },
{ "fg:startup", "nipguidese11.html#nip_label_fg:startup" },
{ "sec:column", "nipguidese11.html#nip_label_sec:column" },
{ "sec:row", "nipguidese11.html#nip_label_sec:row" },
{ "fg:row", "nipguidese11.html#nip_label_fg:row" },
{ "sec:apply", "nipguidese11.html#nip_label_sec:apply" },
{ "sec:batch", "nipguidese11.html#nip_label_sec:batch" },
{ "sec:error", "nipguidese11.html#nip_label_sec:error" },
{ "sec:diaref", "nipguidese11.html#nip_label_sec:diaref" },
{ "sec:menu-math", "nipguidese18.html#nip_label_sec:menu-math" },
{ "sec:ir", "nipguidech3.html#nip_label_sec:ir" },
{ "sec:mosaicing", "nipguidese5.html#nip_label_sec:mosaicing" },
{ "sec:pieces", "nipguidese5.html#nip_label_sec:pieces" },
{ "sec:tutorial", "nipguidech2.html#nip_label_sec:tutorial" },
{ "sec:reference", "nipguidech4.html#nip_label_sec:reference" },
{ "sec:class", "nipguidese32.html#nip_label_sec:class" },
{ "sec:inheritance", "nipguidese32.html#nip_label_sec:inheritance" },
{ "sec:balance", "nipguidese6.html#nip_label_sec:balance" },
{ "sec:irtut", "nipguidese2.html#nip_label_sec:irtut" },
{ "fg:loadsamples", "nipguidese2.html#nip_label_fg:loadsamples" },
{ "fg:readyjoin", "nipguidese2.html#nip_label_fg:readyjoin" },
{ "fg:joined", "nipguidese2.html#nip_label_fg:joined" },
{ "sec:config", "nipguideap1.html#nip_label_sec:config" },
{ "sec:menu-image", "nipguidese17.html#nip_label_sec:menu-image" },
{ "sec:callvips", "nipguidese36.html#nip_label_sec:callvips" },
